@@ -14,7 +14,6 @@ from astropy.utils import deprecated
 from sklearn import metrics
 from sklearn.multiclass import LabelBinarizer
 from ..io.dataset import load_any_resource
-from sklearn.preprocessing import label_binarize
 
 
 __all__ = ['plot_resolution',
@@ -597,7 +596,7 @@ def plot_resolution(bins, res, log=False, ax=None, **kwargs):
     if 'fmt' not in kwargs:
         kwargs['fmt'] = 'o'
 
-    ax.errorbar(x, res[:, 0], xerr=(bins[1:] - bins[:-1]) / 2.,
+    ax.errorbar(x, res[:, 0], xerr=[x - bins[:-1], bins[1:] - x],
                 yerr=(res[:, 0] - res[:, 1], res[:, 2] - res[:, 0]), **kwargs)
 
     ax.set_title('Resolution')
@@ -638,7 +637,7 @@ def plot_effective_area_per_energy(simu_energy, reco_energy, simulated_area, ax=
     ax.spines["right"].set_visible(False)
     ax.get_xaxis().tick_bottom()
     ax.get_yaxis().tick_left()
-    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
+    ax.set_xlabel(r'$E_T$ [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
     ax.set_xscale('log')
     ax.set_yscale('log')
@@ -676,7 +675,7 @@ def plot_effective_area_cta_requirement(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
+    ax.set_xlabel(r'$E_T$ [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
 
     if not 'label' in kwargs:
@@ -710,7 +709,7 @@ def plot_effective_area_cta_performance(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
+    ax.set_xlabel(r'$E_T$ [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
 
     if not 'label' in kwargs:
@@ -744,7 +743,7 @@ def plot_sensitivity_cta_requirement(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
     ax.set_ylabel(r'Flux Sensitivity $[erg.cm^{-2}.s^{-1}]$')
 
     if not 'label' in kwargs:
@@ -780,7 +779,7 @@ def plot_sensitivity_cta_performance(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
     ax.set_ylabel(r'Flux Sensitivity $[erg.cm^{-2}.s^{-1}]$')
 
     if not 'label' in kwargs:
@@ -914,7 +913,7 @@ def plot_angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, reco_en
             kwargs['fmt'] = 'o'
 
         ax.set_ylabel('Angular Resolution [deg]')
-        ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+        ax.set_xlabel(r'$E_R$ [TeV]')
         ax.set_xscale('log')
         ax.set_title('Angular resolution')
 
@@ -950,7 +949,7 @@ def plot_angular_resolution_cta_requirement(cta_site, ax=None, **kwargs):
     ax.plot(e_cta, ar_cta, **kwargs)
 
     ax.set_ylabel(r'Angular Resolution [deg]')
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
 
     ax.set_xscale('log')
     ax.set_title('Angular resolution')
@@ -985,7 +984,7 @@ def plot_angular_resolution_cta_performance(cta_site, ax=None, **kwargs):
     ax.plot(e_cta, ar_cta, **kwargs)
     ax.set_xscale('log')
     ax.set_ylabel('Angular resolution [deg]')
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
     ax.set_title('Angular resolution')
     ax.grid('on', which='both')
     ax.legend()
@@ -1237,7 +1236,7 @@ def plot_energy_bias(simu_energy, reco_energy, ax=None, **kwargs):
         kwargs['fmt'] = 'o'
 
     ax.set_ylabel("bias (median($E_{reco}/E_{simu}$ - 1)")
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
     ax.set_xscale('log')
     ax.set_title('Energy bias')
 
@@ -1284,7 +1283,7 @@ def plot_energy_resolution(simu_energy, reco_energy,
             kwargs['fmt'] = 'o'
 
         ax.set_ylabel(r"$(\Delta E/E)_{68}$")
-        ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+        ax.set_xlabel(r'$E_R$ [TeV]')
         ax.set_xscale('log')
         ax.set_title('Energy resolution')
 
@@ -1320,7 +1319,7 @@ def plot_energy_resolution_cta_requirement(cta_site, ax=None, **kwargs):
         kwargs['label'] = "CTA requirement {}".format(cta_site)
 
     ax.set_ylabel(r"$(\Delta E/E)_{68}$")
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
     ax.plot(e_cta, ar_cta, **kwargs)
     ax.set_xscale('log')
     ax.grid('on', which='both')
@@ -1352,7 +1351,7 @@ def plot_energy_resolution_cta_performance(cta_site, ax=None, **kwargs):
         kwargs['label'] = "CTA performance {}".format(cta_site)
 
     ax.set_ylabel(r"$(\Delta E/E)_{68}$")
-    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
+    ax.set_xlabel(r'$E_R$ [TeV]')
     ax.plot(e_cta, ar_cta, **kwargs)
     ax.set_xscale('log')
     ax.grid('on', which='both')
@@ -1648,7 +1647,7 @@ def plot_effective_area_per_energy_power_law(emin, emax, total_number_events, sp
     ax.spines["right"].set_visible(False)
     ax.get_xaxis().tick_bottom()
     ax.get_yaxis().tick_left()
-    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
+    ax.set_xlabel(r'$E_T$ [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
     ax.set_xscale('log')
     ax.set_yscale('log')
@@ -1901,7 +1900,7 @@ def plot_roc_curve(simu_type, reco_proba,
     ax.plot([0, 1], [0, 1], '--', color='black')
     ax.axis('equal')
     ax.legend(loc=4)
-
+    ax.grid('on')
     return ax
 
 
@@ -1916,7 +1915,7 @@ def plot_roc_curve_multiclass(simu_type, reco_proba,
     ----------
     simu_type: `numpy.ndarray`
         true labels: int, float or str
-    reco_proba: `dict` of `numpy.ndarray` of shape `(len(simu_type), )`
+    reco_proba: `dict` of `numpy.ndarray` of shape `(len(simu_type), len(set(simu_type))`
         reconstruction probability for each class in `simu_type`, values must be between 0 and 1
     pos_label : int or str, default=None
         The label of the positive class.
@@ -1981,7 +1980,7 @@ def plot_roc_curve_multiclass(simu_type, reco_proba,
     ax.plot([0, 1], [0, 1], '--', color='black')
     ax.legend(loc=4)
     ax.axis('equal')
-
+    ax.grid('on')
     return ax
 
 
@@ -2035,6 +2034,7 @@ def plot_roc_curve_gammaness(simu_type, gammaness,
     ax.set_title("gamma ROC curve")
     ax.set_xlabel("gamma false positive rate")
     ax.set_ylabel("gamma true positive rate")
+    ax.grid('on')
     return ax
 
 
@@ -2079,7 +2079,7 @@ def plot_roc_curve_gammaness_per_energy(simu_type, gammaness, simu_energy, gamma
     gammas = simu_type == gamma_label
     non_gammas = simu_type != gamma_label
     gamma_energy = simu_energy[gammas]
-    binarized_label = label_binarize(simu_type, [gamma_label]).ravel()  # binarize in a gamma vs all fashion
+    binarized_label = (simu_type == gamma_label).astype(int)  # binarize in a gamma vs all fashion
 
     if energy_bins is None:
         irf = ana.irf_cta()
@@ -2110,8 +2110,7 @@ def plot_roc_curve_gammaness_per_energy(simu_type, gammaness, simu_energy, gamma
             counter += 2
 
     ax.legend(loc=4)
-    ax.grid()
-
+    ax.grid('on')
     return ax
 
 
